@@ -10,7 +10,7 @@ require HTML::DOM::Element;
 require HTML::DOM::NodeList::Magic;
 #require HTML::DOM::Collection::Elements;
 
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = qw'HTML::DOM::Element';
 
 use overload fallback => 1,
@@ -358,7 +358,8 @@ sub make_request
     if ($method ne "post") {
 	require HTTP::Request;
 	$uri = URI->new($uri, "http");
-	$uri->query_form(@{_apply_charset \@charsets, \@form});
+	$uri->can('query_form')
+	 and $uri->query_form(@{_apply_charset \@charsets, \@form});
 	return HTTP::Request->new(GET => $uri);
     }
     else  {
@@ -406,7 +407,7 @@ package HTML::DOM::NodeList::Radio; # solely for HTML::Form compatibility
 use Carp 'croak';
 require HTML::DOM::NodeList;
 
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = qw'HTML::DOM::NodeList';
 
 sub type { 'radio' }
@@ -478,7 +479,7 @@ use warnings;
 
 use Scalar::Util 'weaken';
 
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 
 require HTML::DOM::Collection;
 our @ISA = 'HTML::DOM::Collection';
@@ -655,7 +656,7 @@ L<HTML::Form>
 # ------- HTMLSelectElement interface ---------- #
 
 package HTML::DOM::Element::Select;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = 'HTML::DOM::Element';
 
 use overload fallback=>1, '@{}' => sub { shift->options };
@@ -749,7 +750,7 @@ package HTML::DOM::Collection::Options;
 use strict;
 use warnings;
 
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 
 use Carp 'croak';
 use constant::lexical sel => 5; # must not conflict with super
@@ -825,7 +826,7 @@ sub length { # override
 # ------- HTMLOptGroupElement interface ---------- #
 
 package HTML::DOM::Element::OptGroup;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = 'HTML::DOM::Element';
 
 sub label  { shift->_attr( label => @_) }
@@ -835,7 +836,7 @@ sub label  { shift->_attr( label => @_) }
 # ------- HTMLOptionElement interface ---------- #
 
 package HTML::DOM::Element::Option;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -946,7 +947,7 @@ sub _reset { delete shift->{_HTML_DOM_sel} }
 # ------- HTMLInputElement interface ---------- #
 
 package HTML::DOM::Element::Input;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = qw'HTML::DOM::Element';
 
 use Carp 'croak';
@@ -1155,7 +1156,7 @@ sub content {
 # ------- HTMLTextAreaElement interface ---------- #
 
 package HTML::DOM::Element::TextArea;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = qw'HTML::DOM::Element';
 
 sub defaultValue { # same as HTML::DOM::Element::Title::text
@@ -1203,7 +1204,7 @@ sub _reset {
 # ------- HTMLButtonElement interface ---------- #
 
 package HTML::DOM::Element::Button;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1218,7 +1219,7 @@ sub value      { shift->attr( value       => @_) }
 # ------- HTMLLabelElement interface ---------- #
 
 package HTML::DOM::Element::Label;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1228,7 +1229,7 @@ sub htmlFor { shift->_attr( for       => @_) }
 # ------- HTMLFieldSetElement interface ---------- #
 
 package HTML::DOM::Element::FieldSet;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
@@ -1236,7 +1237,7 @@ our @ISA = qw'HTML::DOM::Element';
 # ------- HTMLLegendElement interface ---------- #
 
 package HTML::DOM::Element::Legend;
-our $VERSION = '0.038';
+our $VERSION = '0.039';
 our @ISA = qw'HTML::DOM::Element';
 
 *form = \&HTML::DOM::Element::Select::form;
